@@ -1,6 +1,6 @@
 import numpy as np
 from scipy.special import gamma
-from scipy.stats import multivariate_normal, norm
+from scipy.stats import multivariate_normal, norm, lognorm, expon
 
 from abcpy.probabilisticmodels import ProbabilisticModel, Continuous, InputConnector
 
@@ -582,3 +582,195 @@ class MultiStudentT(ProbabilisticModel, Continuous):
         density = normalizing_const * pow(tmp, -((df + p) / 2.))
         self.calculated_pdf = density
         return density
+
+
+class LogNormal(ProbabilisticModel, Continuous):
+    def __init__(self, parameters, name='LogNormal'):
+        """
+        This class implements a probabilistic model following a Lognormal distribution with mean mu and variance sigma.
+
+        Parameters
+        ----------
+        parameters: list
+            Contains the probabilistic models and hyperparameters from which the model derives.
+            The list has two entries: from the first entry mean of the underlying normal distribution and from the second entry variance of the underlying normal
+            distribution is derived.
+            Note that the second value of the list is strictly greater than 0.
+
+        name: string
+            The name that should be given to the probabilistic model in the journal file.
+        """
+
+        if not isinstance(parameters, list):
+            raise TypeError('Input for LogNormal has to be of type list.')
+        if len(parameters) < 2:
+            raise ValueError('Input for LogNormal has to be of length 2.')
+
+        input_parameters = InputConnector.from_list(parameters)
+        super(LogNormal, self).__init__(input_parameters, name)
+        self.visited = False
+
+    def _check_input(self, input_values):
+        """
+        Returns True if the standard deviation is negative.
+        """
+        if len(input_values) != 2:
+            return False
+
+        if input_values[1] <= 0:
+            return False
+        return True
+
+    def _check_output(self, parameters):
+        """
+        Checks parameter values that are given as fixed values.
+        """
+        return True
+
+    def forward_simulate(self, input_values, k, rng=np.random.RandomState(), mpi_comm=None):
+        """
+        Samples from a normal distribution using the current values for each probabilistic model from which the model derives.
+
+        Parameters
+        ----------
+        input_values: list
+            List of input parameters, in the same order as specified in the InputConnector passed to the init function
+        k: integer
+            The number of samples that should be drawn.
+        rng: Random number generator
+            Defines the random number generator to be used. The default value uses a random seed to initialize the generator.
+
+        Returns
+        -------
+        list: [np.ndarray]
+            A list containing the sampled values as np-array.
+        """
+
+        mu = input_values[0]
+        sigma = input_values[1]
+        result = np.array(rng.lognormal(mu, sigma, k))
+        return [np.array([x]).reshape(-1, ) for x in result]
+
+    def get_output_dimension(self):
+        return 1
+        # Why does the following not work here?
+        # return self._dimension
+
+    def pdf(self, input_values, x):
+        """
+        Calculates the probability density function at point x.
+        Commonly used to determine whether perturbed parameters are still valid according to the pdf.
+
+        Parameters
+        ----------
+        input_values: list
+            List of input parameters of the from [mu, sigma]
+        x: list
+            The point at which the pdf should be evaluated.
+
+        Returns
+        -------
+        Float:
+            The evaluated pdf at point x.
+        """
+
+        mu = input_values[0]
+        sigma = input_values[1]
+        pdf = lognorm(scale=np.exp(mu), s=sigma).pdf(x)
+        self.calculated_pdf = pdf
+        return pdf
+
+
+class Exponential(ProbabilisticModel, Continuous):
+    def __init__(self, parameters, name='Exponential'):
+        """
+        This class implements a probabilistic model following a normal distribution with mean mu and variance sigma.
+
+        Parameters
+        ----------
+        parameters: list
+            Contains the probabilistic models and hyperparameters from which the model derives.
+            The list has one entry: the rate $\lambda$ of the exponential distribution, that has therefore pdf:
+                            f(x; \lambda) = \lambda \exp(-\lambda x ),
+        name: string
+            The name that should be given to the probabilistic model in the journal file.
+        """
+
+        if not isinstance(parameters, list):
+            raise TypeError('Input for Exponential has to be of type list.')
+        if len(parameters) != 1:
+            raise ValueError('Input for Exponential has to be of length 1.')
+
+        input_parameters = InputConnector.from_list(parameters)
+        super(Exponential, self).__init__(input_parameters, name)
+        self.visited = False
+
+    def _check_input(self, input_values):
+        """
+        Returns True if the standard deviation is negative.
+        """
+        if len(input_values) != 1:
+            return False
+
+        if input_values[0] <= 0:
+            return False
+        return True
+
+    def _check_output(self, parameters):
+        """
+        Checks parameter values that are given as fixed values.
+        """
+        return True
+
+    def forward_simulate(self, input_values, k, rng=np.random.RandomState(), mpi_comm=None):
+        """
+        Samples from a normal distribution using the current values for each probabilistic model from which the model derives.
+
+        Parameters
+        ----------
+        input_values: list
+            List of input parameters, in the same order as specified in the InputConnector passed to the init function
+        k: integer
+            The number of samples that should be drawn.
+        rng: Random number generator
+            Defines the random number generator to be used. The default value uses a random seed to initialize the generator.
+
+        Returns
+        -------
+        list: [np.ndarray]
+            A list containing the sampled values as np-array.
+        """
+
+        rate = input_values[0]
+        scale = 1 / rate
+        result = np.array(rng.exponential(scale, k))
+        return [np.array([x]).reshape(-1, ) for x in result]
+
+    def get_output_dimension(self):
+        return 1
+        # Why does the following not work here?
+        # return self._dimension
+
+    def pdf(self, input_values, x):
+        """
+        Calculates the probability density function at point x.
+        Commonly used to determine whether perturbed parameters are still valid according to the pdf.
+
+        Parameters
+        ----------
+        input_values: list
+            List of input parameters of the from [rate]
+        x: list
+            The point at which the pdf should be evaluated.
+
+        Returns
+        -------
+        Float:
+            The evaluated pdf at point x.
+        """
+
+        rate = input_values[0]
+        scale = 1 / rate
+        pdf = expon(scale=scale).pdf(x)
+        self.calculated_pdf = pdf
+        return pdf
